@@ -72,7 +72,7 @@ static gboolean run_via_dbus(int argc, char **argv)
 			result = FALSE;
 		g_free(cwd);
 	}
-	if (global_options_commandv)
+	if (result && global_options_commandv)
 	{
 		const char *e = "-e";
 
@@ -115,7 +115,7 @@ static DBusHandlerResult new_term_listener(DBusConnection *connection,
 	if (argc)
 	{
 		global_options_preparse_argv_for_execute(&argc, argv, TRUE);
-		global_options_init(argc, argv);
+		global_options_init(&argc, &argv);
 	}
 	roxterm_launch();
 	if (!dbus_message_get_no_reply(message))
@@ -151,7 +151,7 @@ int main(int argc, char **argv)
 		dlg_critical(NULL, _("Missing command after -e/--execute option"));
 		return 1;
 	}
-	global_options_init(argc, argv);
+	global_options_init(&argc, &argv);
 
 	dbus_ok = rtdbus_init();
 	if (dbus_ok)
